@@ -26,6 +26,7 @@
 #include "RestStateMessage.h"
 #include "WebService/Request.h"
 #include "LastFmSettings.h"
+#include "User.h"
 #include "WebService.h"
 
 #include "lastfmapplication.h"
@@ -40,8 +41,8 @@
     static const int k_helloFontSize = 18;
     static const int k_standardFontSize = 11;
 #else
-    static const int k_helloFontSize = 24;
-    static const int k_standardFontSize = 18;
+    static const int k_helloFontSize = 20;
+    static const int k_standardFontSize = 13;
 #endif
 
 
@@ -57,19 +58,19 @@ RestStateWidget::RestStateWidget( QWidget* parent )
         : WatermarkWidget( parent ),
           m_play_enabled( false )
 {
-    //TODO give title tooltips for the tag keyword
-
     ui.setupUi( this );
-
+    
+    ui.label3->setOpenExternalLinks( true );
+    m_label3_original_text = ui.label3->text();
+    
     setFontPixelSize( ui.hello, k_helloFontSize );
     setFontPixelSize( ui.label1, k_standardFontSize );
     setFontPixelSize( ui.label2, k_standardFontSize );
+    setFontPixelSize( ui.label3, k_standardFontSize );
 
     #ifdef Q_WS_MAC
         QSize s = QPixmap(":/mac/RestStateWidgetCombo.png").size();
 
-        ui.label2->setText( tr("or listen to your music in %1.", "%1 is a media player").arg( "iTunes" ) );
-
         if ( The::settings().appLanguage() == "en" )
         {
             // we only show this graphic for english as other languages are too wide
@@ -102,6 +103,7 @@ RestStateWidget::RestStateWidget( QWidget* parent )
 
     #elif defined LINUX
 
+        ui.label1->hide(); //no iTunes on Linux
         ui.label2->hide(); //no plugins on Linux
 
         QList<QWidget*> widgets; widgets << ui.edit << ui.combo << ui.play;
@@ -117,6 +119,8 @@ RestStateWidget::RestStateWidget( QWidget* parent )
     connect( ui.edit, SIGNAL( textChanged( QString ) ), SLOT( onEditTextChanged( QString ) ) );
     connect( ui.play, SIGNAL( clicked() ), SLOT( onPlayClicked() ) );
 
+    connect( ui.label2, SIGNAL(linkActivated( QString )), SLOT(openProfile()) );
+
     connect( &The::settings(), SIGNAL( userSwitched( LastFmUserSettings& ) ), SLOT( onUserChanged( LastFmUserSettings& ) ) );
     connect( The::webService(), SIGNAL( handshakeResult( Handshake* ) ), SLOT( onHandshaken( Handshake* ) ) );
 
@@ -147,16 +151,16 @@ RestStateWidget::updatePlayerNames()
 
         if ( plugins.count() )
         {
-            QString text = tr( "or listen to your music in %1 or %2.",
-                    "%1 is a list of plugins, eg. 'Foobar, Winamp, Windows Media Player'" );
+            QString text = tr("Start listening with %1 or %2 to update your Last.fm profile.", 
+                              "%1 is a list of at least two comma-separated plugins, eg. 'Foobar, Winamp, Windows Media Player'" );
 
-            ui.label2->setText( text.arg( plugins.join( ", " ) ).arg( last_plugin ) );
+            ui.label1->setText( text.arg( plugins.join( ", " ) ).arg( last_plugin ) );
         }
         else
-            ui.label2->setText( tr( "or listen to your music in %1.", "%1 is a media player" ).arg( last_plugin ) );
+            ui.label1->setText( tr( "Start listening with %1 to update your Last.fm profile." ).arg( last_plugin ) );
     }
     else
-        ui.label2->setText( tr( "or install a player plugin to scrobble music from your media player." ) );
+        ui.label1->setText( tr( "You must install a scrobbling plugin in order to update your Last.fm profile." ) );
 #endif
 }
 
@@ -170,12 +174,20 @@ RestStateWidget::onUserChanged( LastFmUserSettings& user )
     qDeleteAll( findChildren<RestStateMessage*>() );
 
     QString const username = user.username().toLower();
+    
+    ui.label3->clear();
+    ui.combo->setEnabled( false );
+    ui.edit->setEnabled( false );
+    ui.play->setEnabled( false );
+    ui.label3->setEnabled( false );
 }
 
 
 void
 RestStateWidget::onHandshaken( Handshake* handshake )
 {
+    setFreeTrialStatus( handshake->freeTrial() );
+
     #ifndef Q_WS_MAC
         const bool noPluginsInstalled = The::settings().allPlugins().empty();
     #else
@@ -210,7 +222,31 @@ RestStateWidget::onHandshaken( Handshake* handshake )
 
     connect( msg, SIGNAL( accepted() ), SLOT( showBootstrapWizard()) );
     connect( msg, SIGNAL( moreHelpClicked() ), SLOT( openBootstrapFaq()) );
+}
 
+
+void
+RestStateWidget::setFreeTrialStatus( int status )
+{
+    ui.label3->setEnabled( true );
+
+    if (status == 2)
+    {
+        ui.combo->setEnabled( false );
+        ui.edit->setEnabled( false );
+        ui.play->setEnabled( false );
+        ui.label3->setText( tr( "<h1>Did you enjoy it?</h1><p>Your free trial has expired. <a href='http://last.fm/subscribe'>Subscribe</a> to keep<br>listening to non-stop, personalised radio!" ) );
+    }
+    else
+    {
+        if (status == 1)
+            ui.label3->setText( tr("<b>Or try out Last.fm radio with your free trial.</b><br>Type your favourite artist or tag:") );
+        else
+            ui.label3->setText( tr("Enter an <b>artist</b> or <b>tag</b> to start<br>listening to Last.fm radio.") );
+        ui.combo->setEnabled( true );
+        ui.edit->setEnabled( true );
+        ui.play->setEnabled( true );
+    }
 }
 
 
@@ -313,3 +349,11 @@ RestStateWidget::openBootstrapFaq()
     QDesktopServices::openUrl(
         QUrl( "http://" + UnicornUtils::localizedHostName( The::settings().appLanguage() ) + "/help/faq/" ) ); // ?category=Listening History Importing" ) );
 }
+
+
+void
+RestStateWidget::openProfile()
+{
+    QString const localizedHost = UnicornUtils::localizedHostName( The::settings().appLanguage() );
+    QDesktopServices::openUrl( "http://" + localizedHost + "/user/" + QUrl::toPercentEncoding( The::settings().currentUsername() ) );
+}
