@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 - 2007 by                                          *
+ *   Copyright (C) 2005 - 2008 by                                          *
  *      Christian Muehlhaeuser, Last.fm Ltd <chris@last.fm>                *
  *      Erik Jaelevik, Last.fm Ltd <erik@last.fm>                          *
  *                                                                         *
@@ -25,6 +25,7 @@
 #include "logger.h"
 #include "LastFmSettings.h"
 
+#include <QMessageBox>
 #include <QPainter>
 #include <QShortcut>
 
@@ -56,11 +57,13 @@ AboutDialog::AboutDialog( QWidget* parent )
     QString labelText = tr( "Version %1" ).arg( The::settings().version() );
     foreach(QString v, The::settings().allPlugins())
         labelText += '\n' + v;
-    labelText += '\n' + tr( "Copyright 2007 Last.fm Ltd. (C)" );
+    labelText += '\n' + tr( "Copyright 2008 Last.fm Ltd. (C)" );
     ui.labelInfo->setText( labelText );
 
     adjustSize();
     setFixedSize( sizeHint() );
+    
+    new QShortcut( QKeySequence( Qt::Key_M, Qt::Key_L, Qt::Key_I ), this, SLOT(onEasterEgg()) );
 }
 
 
@@ -69,3 +72,19 @@ AboutDialog::paintEvent( QPaintEvent* )
 {
     QPainter( this ).drawPixmap( 0, 0, m_watermark );
 }
+
+
+void
+AboutDialog::onEasterEgg()
+{
+    QMessageBox::information( this, "Easter Egg",
+            "<erik> jono: yes! eriktesttest26 now can haz profile!\n"
+            "<jono> yay :-d\n"
+            "<jono> jono == happy\n"
+            "<max> that evaluates to true I guess\n"
+            "<jono> yeah\n"
+            "<jono> ++jono.happiness\n"
+            "<erik> pretty nasty encapsulation breakage there jono\n"
+            "<erik> hide your implementation, man\n"
+            "<jono> I'm so happy I can't contain myself ;-)" );
+}
