@@ -38,6 +38,9 @@ class AboutDialog : public QDialog
     protected:
         virtual void paintEvent( QPaintEvent* );
 
+    private slots:
+        void onEasterEgg();
+
     private:
         Ui::AboutDialog ui;
 
