@@ -21,6 +21,8 @@
  *   51 Franklin Steet, Fifth Floor, Boston, MA  02110-1301, USA.          *
  ***************************************************************************/
 
+#include <QDesktopServices>
+
 #include "container.h"
 
 #include "aboutdialog.h"
@@ -52,7 +54,6 @@
 #include "RestStateWidget.h"
 #include "updatewizard.h"
 #include "User.h"
-#include "volumeslider.h"
 #include "WebService.h"
 #include "WebService/Request.h"
 
@@ -495,8 +496,8 @@ Container::restoreState()
 
     // figure out minimum width of our toolbar (this will change due to translations!)
     int w = width();
-    QByteArray geometry = The::settings().containerGeometry();
-    if ( geometry.isEmpty() )
+    m_geometry = The::settings().containerGeometry();
+    if ( m_geometry.isEmpty() )
     {
         w = 0;
         QList<QAction*> a = ui.toolbar->actions();
@@ -528,14 +529,14 @@ Container::restoreState()
 #ifdef Q_WS_MAC
     // on mac qt returns height without unified toolbar height included :(
     // so first time we have to do it like this
-    if ( geometry.isEmpty() )
+    if ( m_geometry.isEmpty() )
         resize( w, 496 );
     else
-        restoreGeometry( geometry );
+        restoreGeometry( m_geometry );
 #else
-    restoreGeometry( The::settings().containerGeometry() );
+    restoreGeometry( m_geometry );
 
-    if ( geometry.isEmpty() )
+    if ( m_geometry.isEmpty() )
         resize( w, height() );
 #endif
     setWindowState( The::settings().containerWindowState() );
@@ -546,6 +547,7 @@ Container::~Container()
 {
     LOGL( 3, "Saving app state" );
 
+    The::settings().setContainerGeometry( m_geometry );
     The::settings().setContainerWindowState( windowState() );
     The::settings().setVolume( ui.playcontrols.volume->value() );
     The::currentUser().setSidebarEnabled( m_sidebarEnabled );
@@ -701,7 +703,10 @@ Container::event( QEvent* e )
         // for *every* resize and move event. Yay!
 
         if (windowState() != Qt::WindowMaximized)
-            The::settings().setContainerGeometry( saveGeometry() );
+            // Such frequent calls to setContainerGeometry() are very cpu intensive.
+            // Just dump to a QByteArray and save it in the destructor.
+            //The::settings().setContainerGeometry( saveGeometry() );
+            m_geometry = saveGeometry();
     }
 
     if ( e->type() == QEvent::Show )
@@ -782,13 +787,17 @@ Container::onRadioError( RadioError error, const QString& message )
         break;
 
         // Info box
+        case ChangeStation_SubscribersOnly:
+            msgboxTitle = ""; // can't translate yet
+            // FALL THROUGH
+        
         case Radio_SkipLimitExceeded:
         case ChangeStation_NotEnoughContent:
         case ChangeStation_TooFewGroupMembers:
         case ChangeStation_TooFewFans:
         case ChangeStation_TooFewNeighbours:
         case ChangeStation_Unavailable:
-        case ChangeStation_SubscribersOnly:
+
         case ChangeStation_StreamerOffline:
         case ChangeStation_UnknownError:
         case Radio_BadPlaylist:
@@ -805,7 +814,25 @@ Container::onRadioError( RadioError error, const QString& message )
             LastMessageBox::information( msgboxTitle, message );
         }
         break;
+        
+        case Radio_FreeTrialExpired:
+        {
+            ui.restStateWidget->setFreeTrialStatus( 2 );
+            
+            int const r = LastMessageBox::information( 
+                tr("Did you enjoy it?"),
+                tr("Your free trial has expired. <a href='http://last.fm/subscribe'>Subscribe</a> to keep listening to non-stop, personalised radio!"),
+                QMessageBox::Ok | QMessageBox::Cancel,
+                QMessageBox::Ok,
+                QStringList() << tr("Subscribe") << tr("Cancel") );
 
+            if (QMessageBox::Ok == r)
+            {
+                QDesktopServices::openUrl( QUrl("http://last.fm/subscribe") );
+            }
+        }
+        break;
+            
         default:
             Q_ASSERT( !"Is it correct to leave some unhandled?" );
     }
@@ -1587,12 +1614,15 @@ Container::webServiceFailure( Request *r )
 void
 Container::onAltShiftL()
 {
+    Logger* thelog = Logger::the();
+    if (!thelog) return;
+
     #ifdef WIN32
         // The QDesktopServices call doesn't work on Windows
-        QString file = QString::fromStdWString( Logger::GetLogger().GetFilePath() );
+        QString file = QString::fromStdWString( thelog->GetFilePath() );
         ShellExecuteW( 0, 0, (TCHAR*)file.utf16(), 0, 0, SW_SHOWNORMAL );
     #else
-        QDesktopServices::openUrl( QUrl::fromLocalFile( QString::fromStdString( Logger::GetLogger().GetFilePath() ) ) );
+        QDesktopServices::openUrl( QUrl::fromLocalFile( QString::fromStdString( thelog->GetFilePath() ) ) );
     #endif
 }
 
