@@ -200,6 +200,15 @@ public:
         MyQSettings( this ).setValue( "GiveMoreIPodScrobblingFeedback", b );
     }
     
+    void setFreeTrialRanOut()
+    {
+        MyQSettings( this ).setValue( "FreeTrialRanOut", true );
+        emit userChanged( username() );
+    }
+    bool freeTrialRanOut() const
+    {
+        return MyQSettings( this ).value( "FreeTrialRanOut", false ).toBool();
+    }
 
 signals:
     void userChanged( QString username );
