@@ -22,6 +22,7 @@
 #include "Request.h"
 #include "Settings.h"
 #include "WebService.h"
+#include "RadioEnums.h"
 
 
 ChangeStationRequest::ChangeStationRequest()
@@ -52,7 +53,8 @@ ChangeStationRequest::start()
         // It's a preview/playlist, use getresourceplaylist
         path = "/1.0/webclient/getresourceplaylist.php?sk=" + m_session +
                "&url=lastfm://" + url +
-               "&desktop=1"; // plain text
+               "&desktop=1" +  // plain text
+               "&api_key=9d1bbaef3b443eb97973d44181d04e4b";
 
         m_hasXspf = true;
     }
@@ -62,7 +64,8 @@ ChangeStationRequest::start()
         path = m_basePath +
                "/adjust.php?session=" + m_session +
                "&url=lastfm://" + url +
-               "&lang=" + lang_code;
+               "&lang=" + lang_code +
+               "&api_key=9d1bbaef3b443eb97973d44181d04e4b";
     }
 
     get( path );
@@ -126,6 +129,10 @@ ChangeStationRequest::success( QByteArray data )
                         tr( "The streaming system is offline for maintenance, please try again later." ) );
                     break;
 
+                case 9:
+                    setFailed( ChangeStation_FreeTrialExpired, "" );
+                    break;
+
                 default:
                     setFailed( ChangeStation_UnknownError,
                         tr( "Starting radio failed. Unknown error." ) );
